==> haskell-gtk-0.14.8-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gtk.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk3
version: 0.14.8
id: gtk3-0.14.8-1FoJ0CzaPbTJYdJ9HSy7RX
key: gtk3-0.14.8-1FoJ0CzaPbTJYdJ9HSy7RX
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Gtk+ 3 graphical user interface library
description:
    This is the core library of the Gtk2Hs suite of libraries for Haskell
    based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
    for creating graphical user interfaces.
category: Graphics
author: Axel Simon, Duncan Coutts and many others
exposed: True
indefinite: False
exposed-modules:
    Graphics.UI.Gtk Graphics.UI.Gtk.Abstract.Bin
    Graphics.UI.Gtk.Abstract.Box Graphics.UI.Gtk.Abstract.ButtonBox
    Graphics.UI.Gtk.Abstract.Container
    Graphics.UI.Gtk.Abstract.IMContext Graphics.UI.Gtk.Abstract.Misc
    Graphics.UI.Gtk.Abstract.Object Graphics.UI.Gtk.Abstract.Paned
    Graphics.UI.Gtk.Abstract.Range Graphics.UI.Gtk.Abstract.Scale
    Graphics.UI.Gtk.Abstract.Scrollbar
    Graphics.UI.Gtk.Abstract.Separator Graphics.UI.Gtk.Abstract.Widget
    Graphics.UI.Gtk.ActionMenuToolbar.Action
    Graphics.UI.Gtk.ActionMenuToolbar.ActionGroup
    Graphics.UI.Gtk.ActionMenuToolbar.RadioAction
    Graphics.UI.Gtk.ActionMenuToolbar.RecentAction
    Graphics.UI.Gtk.ActionMenuToolbar.ToggleAction
    Graphics.UI.Gtk.ActionMenuToolbar.UIManager Graphics.UI.Gtk.Builder
    Graphics.UI.Gtk.Buttons.Button Graphics.UI.Gtk.Buttons.CheckButton
    Graphics.UI.Gtk.Buttons.LinkButton
    Graphics.UI.Gtk.Buttons.RadioButton
    Graphics.UI.Gtk.Buttons.ScaleButton
    Graphics.UI.Gtk.Buttons.ToggleButton
    Graphics.UI.Gtk.Buttons.VolumeButton Graphics.UI.Gtk.Cairo
    Graphics.UI.Gtk.Display.AccelLabel Graphics.UI.Gtk.Display.Image
    Graphics.UI.Gtk.Display.InfoBar Graphics.UI.Gtk.Display.Label
    Graphics.UI.Gtk.Display.LevelBar
    Graphics.UI.Gtk.Display.ProgressBar Graphics.UI.Gtk.Display.Spinner
    Graphics.UI.Gtk.Display.StatusIcon
    Graphics.UI.Gtk.Display.Statusbar Graphics.UI.Gtk.Embedding.Plug
    Graphics.UI.Gtk.Embedding.Socket Graphics.UI.Gtk.Embedding.Types
    Graphics.UI.Gtk.Entry.Editable Graphics.UI.Gtk.Entry.Entry
    Graphics.UI.Gtk.Entry.EntryBuffer
    Graphics.UI.Gtk.Entry.EntryCompletion Graphics.UI.Gtk.Entry.HScale
    Graphics.UI.Gtk.Entry.SpinButton Graphics.UI.Gtk.Entry.VScale
    Graphics.UI.Gtk.Gdk.AppLaunchContext Graphics.UI.Gtk.Gdk.Cursor
    Graphics.UI.Gtk.Gdk.Display Graphics.UI.Gtk.Gdk.DisplayManager
    Graphics.UI.Gtk.Gdk.DrawWindow Graphics.UI.Gtk.Gdk.EventM
    Graphics.UI.Gtk.Gdk.Events Graphics.UI.Gtk.Gdk.GLContext
    Graphics.UI.Gtk.Gdk.Gdk Graphics.UI.Gtk.Gdk.Keymap
    Graphics.UI.Gtk.Gdk.Keys Graphics.UI.Gtk.Gdk.Pixbuf
    Graphics.UI.Gtk.Gdk.PixbufAnimation Graphics.UI.Gtk.Gdk.Screen
    Graphics.UI.Gtk.General.Clipboard
    Graphics.UI.Gtk.General.CssProvider Graphics.UI.Gtk.General.Drag
    Graphics.UI.Gtk.General.Enums Graphics.UI.Gtk.General.General
    Graphics.UI.Gtk.General.IconFactory
    Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
    Graphics.UI.Gtk.General.Selection Graphics.UI.Gtk.General.Settings
    Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
    Graphics.UI.Gtk.General.StyleContext
    Graphics.UI.Gtk.General.StyleProvider
    Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
    Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
    Graphics.UI.Gtk.Layout.Grid Graphics.UI.Gtk.Layout.HBox
    Graphics.UI.Gtk.Layout.HButtonBox Graphics.UI.Gtk.Layout.HPaned
    Graphics.UI.Gtk.Layout.Layout Graphics.UI.Gtk.Layout.Notebook
    Graphics.UI.Gtk.Layout.Overlay Graphics.UI.Gtk.Layout.Stack
    Graphics.UI.Gtk.Layout.StackSwitcher Graphics.UI.Gtk.Layout.Table
    Graphics.UI.Gtk.Layout.VBox Graphics.UI.Gtk.Layout.VButtonBox
    Graphics.UI.Gtk.Layout.VPaned
    Graphics.UI.Gtk.MenuComboToolbar.CheckMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.ComboBox
    Graphics.UI.Gtk.MenuComboToolbar.ImageMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.Menu
    Graphics.UI.Gtk.MenuComboToolbar.MenuBar
    Graphics.UI.Gtk.MenuComboToolbar.MenuItem
    Graphics.UI.Gtk.MenuComboToolbar.MenuShell
    Graphics.UI.Gtk.MenuComboToolbar.MenuToolButton
    Graphics.UI.Gtk.MenuComboToolbar.RadioMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.RadioToolButton
    Graphics.UI.Gtk.MenuComboToolbar.SeparatorMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.SeparatorToolItem
    Graphics.UI.Gtk.MenuComboToolbar.TearoffMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.ToggleToolButton
    Graphics.UI.Gtk.MenuComboToolbar.ToolButton
    Graphics.UI.Gtk.MenuComboToolbar.ToolItem
    Graphics.UI.Gtk.MenuComboToolbar.ToolItemGroup
    Graphics.UI.Gtk.MenuComboToolbar.ToolPalette
    Graphics.UI.Gtk.MenuComboToolbar.Toolbar
    Graphics.UI.Gtk.Misc.Accessible Graphics.UI.Gtk.Misc.Adjustment
    Graphics.UI.Gtk.Misc.Arrow Graphics.UI.Gtk.Misc.Calendar
    Graphics.UI.Gtk.Misc.DrawingArea Graphics.UI.Gtk.Misc.EventBox
    Graphics.UI.Gtk.Misc.GLArea Graphics.UI.Gtk.Misc.HandleBox
    Graphics.UI.Gtk.Misc.IMContextSimple
    Graphics.UI.Gtk.Misc.IMMulticontext Graphics.UI.Gtk.Misc.SizeGroup
    Graphics.UI.Gtk.Misc.Switch Graphics.UI.Gtk.Misc.Tooltip
    Graphics.UI.Gtk.Misc.Viewport Graphics.UI.Gtk.ModelView
    Graphics.UI.Gtk.ModelView.CellEditable
    Graphics.UI.Gtk.ModelView.CellLayout
    Graphics.UI.Gtk.ModelView.CellRenderer
    Graphics.UI.Gtk.ModelView.CellRendererAccel
    Graphics.UI.Gtk.ModelView.CellRendererCombo
    Graphics.UI.Gtk.ModelView.CellRendererPixbuf
    Graphics.UI.Gtk.ModelView.CellRendererProgress
    Graphics.UI.Gtk.ModelView.CellRendererSpin
    Graphics.UI.Gtk.ModelView.CellRendererSpinner
    Graphics.UI.Gtk.ModelView.CellRendererText
    Graphics.UI.Gtk.ModelView.CellRendererToggle
    Graphics.UI.Gtk.ModelView.CellView
    Graphics.UI.Gtk.ModelView.CustomStore
    Graphics.UI.Gtk.ModelView.IconView
    Graphics.UI.Gtk.ModelView.ListStore
    Graphics.UI.Gtk.ModelView.TreeDrag
    Graphics.UI.Gtk.ModelView.TreeModel
    Graphics.UI.Gtk.ModelView.TreeModelFilter
    Graphics.UI.Gtk.ModelView.TreeModelSort
    Graphics.UI.Gtk.ModelView.TreeRowReference
    Graphics.UI.Gtk.ModelView.TreeSelection
    Graphics.UI.Gtk.ModelView.TreeSortable
    Graphics.UI.Gtk.ModelView.TreeStore
    Graphics.UI.Gtk.ModelView.TreeView
    Graphics.UI.Gtk.ModelView.TreeViewColumn
    Graphics.UI.Gtk.Multiline.TextBuffer
    Graphics.UI.Gtk.Multiline.TextIter
    Graphics.UI.Gtk.Multiline.TextMark
    Graphics.UI.Gtk.Multiline.TextTag
    Graphics.UI.Gtk.Multiline.TextTagTable
    Graphics.UI.Gtk.Multiline.TextView Graphics.UI.Gtk.Ornaments.Frame
    Graphics.UI.Gtk.Ornaments.HSeparator
    Graphics.UI.Gtk.Ornaments.VSeparator
    Graphics.UI.Gtk.Printing.PageSetup
    Graphics.UI.Gtk.Printing.PaperSize
    Graphics.UI.Gtk.Printing.PrintContext
    Graphics.UI.Gtk.Printing.PrintOperation
    Graphics.UI.Gtk.Printing.PrintSettings
    Graphics.UI.Gtk.Recent.RecentChooser
    Graphics.UI.Gtk.Recent.RecentChooserMenu
    Graphics.UI.Gtk.Recent.RecentChooserWidget
    Graphics.UI.Gtk.Recent.RecentFilter
    Graphics.UI.Gtk.Recent.RecentInfo
    Graphics.UI.Gtk.Recent.RecentManager
    Graphics.UI.Gtk.Scrolling.HScrollbar
    Graphics.UI.Gtk.Scrolling.ScrolledWindow
    Graphics.UI.Gtk.Scrolling.VScrollbar
    Graphics.UI.Gtk.Selectors.ColorButton
    Graphics.UI.Gtk.Selectors.ColorSelection
    Graphics.UI.Gtk.Selectors.ColorSelectionDialog
    Graphics.UI.Gtk.Selectors.FileChooser
    Graphics.UI.Gtk.Selectors.FileChooserButton
    Graphics.UI.Gtk.Selectors.FileChooserDialog
    Graphics.UI.Gtk.Selectors.FileChooserWidget
    Graphics.UI.Gtk.Selectors.FileFilter
    Graphics.UI.Gtk.Selectors.FontButton
    Graphics.UI.Gtk.Selectors.FontSelection
    Graphics.UI.Gtk.Selectors.FontSelectionDialog
    Graphics.UI.Gtk.Selectors.HSV Graphics.UI.Gtk.Windows.AboutDialog
    Graphics.UI.Gtk.Windows.Assistant Graphics.UI.Gtk.Windows.Dialog
    Graphics.UI.Gtk.Windows.Invisible
    Graphics.UI.Gtk.Windows.MessageDialog
    Graphics.UI.Gtk.Windows.OffscreenWindow
    Graphics.UI.Gtk.Windows.Window Graphics.UI.Gtk.Windows.WindowGroup
    Graphics.UI.GtkInternals
hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                Graphics.UI.Gtk.Gdk.PixbufData Graphics.UI.Gtk.General.Structs
                Graphics.UI.Gtk.ModelView.Types Graphics.UI.Gtk.ModelView.Sequence
                Graphics.UI.Gtk.Multiline.Types
                Graphics.UI.Gtk.Abstract.ContainerChildProperties
                Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
abi: 4999a161d24de5f038cabea417a8ac0e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gtk3-0.14.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/gtk3-0.14.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk
hs-libraries: HSgtk3-0.14.8-1FoJ0CzaPbTJYdJ9HSy7RX
extra-libraries:
    gthread-2.0 gtk-3 gdk-3 pangocairo-1.0 pango-1.0 atk-1.0
    cairo-gobject cairo gdk_pixbuf-2.0 gio-2.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/gtk-3.0 /usr/include/at-spi2-atk/2.0
              /usr/include/at-spi-2.0 /usr/include/dbus-1.0
              /usr/lib/dbus-1.0/include /usr/include/gio-unix-2.0/
              /usr/include/cairo /usr/include/pango-1.0 /usr/include/atk-1.0
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/gdk-pixbuf-2.0
depends:
    base-4.10.1.0 array-0.5.2.0 containers-0.5.10.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    glib-0.13.5.0-BeAc7OfNXQoLFL8f9OJjxh
    pango-0.13.4.0-9Tq9kbdD0ux7FY4BsNo9Py
    cairo-0.13.4.2-Dw8Q4OMoxeCeIJxfgPTYN
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             glib-0.13.5.0-BeAc7OfNXQoLFL8f9OJjxh=5806e3854455ad0234d765b23ad774c8
             pango-0.13.4.0-9Tq9kbdD0ux7FY4BsNo9Py=d6545bf58ee0515b92097ed2b160c5e1
             cairo-0.13.4.2-Dw8Q4OMoxeCeIJxfgPTYN=0e668a913017a7446ce6ea0cdd858dab
ld-options: -pthread
haddock-interfaces: /usr/share/doc/haskell-gtk/html/gtk3.haddock
haddock-html: /usr/share/doc/haskell-gtk/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-0.14.8-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gtk.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk3
version: 0.14.8
id: gtk3-0.14.8-1FoJ0CzaPbTJYdJ9HSy7RX
key: gtk3-0.14.8-1FoJ0CzaPbTJYdJ9HSy7RX
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Gtk+ 3 graphical user interface library
description:
    This is the core library of the Gtk2Hs suite of libraries for Haskell
    based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
    for creating graphical user interfaces.
category: Graphics
author: Axel Simon, Duncan Coutts and many others
exposed: True
indefinite: False
exposed-modules:
    Graphics.UI.Gtk Graphics.UI.Gtk.Abstract.Bin
    Graphics.UI.Gtk.Abstract.Box Graphics.UI.Gtk.Abstract.ButtonBox
    Graphics.UI.Gtk.Abstract.Container
    Graphics.UI.Gtk.Abstract.IMContext Graphics.UI.Gtk.Abstract.Misc
    Graphics.UI.Gtk.Abstract.Object Graphics.UI.Gtk.Abstract.Paned
    Graphics.UI.Gtk.Abstract.Range Graphics.UI.Gtk.Abstract.Scale
    Graphics.UI.Gtk.Abstract.Scrollbar
    Graphics.UI.Gtk.Abstract.Separator Graphics.UI.Gtk.Abstract.Widget
    Graphics.UI.Gtk.ActionMenuToolbar.Action
    Graphics.UI.Gtk.ActionMenuToolbar.ActionGroup
    Graphics.UI.Gtk.ActionMenuToolbar.RadioAction
    Graphics.UI.Gtk.ActionMenuToolbar.RecentAction
    Graphics.UI.Gtk.ActionMenuToolbar.ToggleAction
    Graphics.UI.Gtk.ActionMenuToolbar.UIManager Graphics.UI.Gtk.Builder
    Graphics.UI.Gtk.Buttons.Button Graphics.UI.Gtk.Buttons.CheckButton
    Graphics.UI.Gtk.Buttons.LinkButton
    Graphics.UI.Gtk.Buttons.RadioButton
    Graphics.UI.Gtk.Buttons.ScaleButton
    Graphics.UI.Gtk.Buttons.ToggleButton
    Graphics.UI.Gtk.Buttons.VolumeButton Graphics.UI.Gtk.Cairo
    Graphics.UI.Gtk.Display.AccelLabel Graphics.UI.Gtk.Display.Image
    Graphics.UI.Gtk.Display.InfoBar Graphics.UI.Gtk.Display.Label
    Graphics.UI.Gtk.Display.LevelBar
    Graphics.UI.Gtk.Display.ProgressBar Graphics.UI.Gtk.Display.Spinner
    Graphics.UI.Gtk.Display.StatusIcon
    Graphics.UI.Gtk.Display.Statusbar Graphics.UI.Gtk.Embedding.Plug
    Graphics.UI.Gtk.Embedding.Socket Graphics.UI.Gtk.Embedding.Types
    Graphics.UI.Gtk.Entry.Editable Graphics.UI.Gtk.Entry.Entry
    Graphics.UI.Gtk.Entry.EntryBuffer
    Graphics.UI.Gtk.Entry.EntryCompletion Graphics.UI.Gtk.Entry.HScale
    Graphics.UI.Gtk.Entry.SpinButton Graphics.UI.Gtk.Entry.VScale
    Graphics.UI.Gtk.Gdk.AppLaunchContext Graphics.UI.Gtk.Gdk.Cursor
    Graphics.UI.Gtk.Gdk.Display Graphics.UI.Gtk.Gdk.DisplayManager
    Graphics.UI.Gtk.Gdk.DrawWindow Graphics.UI.Gtk.Gdk.EventM
    Graphics.UI.Gtk.Gdk.Events Graphics.UI.Gtk.Gdk.GLContext
    Graphics.UI.Gtk.Gdk.Gdk Graphics.UI.Gtk.Gdk.Keymap
    Graphics.UI.Gtk.Gdk.Keys Graphics.UI.Gtk.Gdk.Pixbuf
    Graphics.UI.Gtk.Gdk.PixbufAnimation Graphics.UI.Gtk.Gdk.Screen
    Graphics.UI.Gtk.General.Clipboard
    Graphics.UI.Gtk.General.CssProvider Graphics.UI.Gtk.General.Drag
    Graphics.UI.Gtk.General.Enums Graphics.UI.Gtk.General.General
    Graphics.UI.Gtk.General.IconFactory
    Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
    Graphics.UI.Gtk.General.Selection Graphics.UI.Gtk.General.Settings
    Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
    Graphics.UI.Gtk.General.StyleContext
    Graphics.UI.Gtk.General.StyleProvider
    Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
    Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
    Graphics.UI.Gtk.Layout.Grid Graphics.UI.Gtk.Layout.HBox
    Graphics.UI.Gtk.Layout.HButtonBox Graphics.UI.Gtk.Layout.HPaned
    Graphics.UI.Gtk.Layout.Layout Graphics.UI.Gtk.Layout.Notebook
    Graphics.UI.Gtk.Layout.Overlay Graphics.UI.Gtk.Layout.Stack
    Graphics.UI.Gtk.Layout.StackSwitcher Graphics.UI.Gtk.Layout.Table
    Graphics.UI.Gtk.Layout.VBox Graphics.UI.Gtk.Layout.VButtonBox
    Graphics.UI.Gtk.Layout.VPaned
    Graphics.UI.Gtk.MenuComboToolbar.CheckMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.ComboBox
    Graphics.UI.Gtk.MenuComboToolbar.ImageMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.Menu
    Graphics.UI.Gtk.MenuComboToolbar.MenuBar
    Graphics.UI.Gtk.MenuComboToolbar.MenuItem
    Graphics.UI.Gtk.MenuComboToolbar.MenuShell
    Graphics.UI.Gtk.MenuComboToolbar.MenuToolButton
    Graphics.UI.Gtk.MenuComboToolbar.RadioMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.RadioToolButton
    Graphics.UI.Gtk.MenuComboToolbar.SeparatorMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.SeparatorToolItem
    Graphics.UI.Gtk.MenuComboToolbar.TearoffMenuItem
    Graphics.UI.Gtk.MenuComboToolbar.ToggleToolButton
    Graphics.UI.Gtk.MenuComboToolbar.ToolButton
    Graphics.UI.Gtk.MenuComboToolbar.ToolItem
    Graphics.UI.Gtk.MenuComboToolbar.ToolItemGroup
    Graphics.UI.Gtk.MenuComboToolbar.ToolPalette
    Graphics.UI.Gtk.MenuComboToolbar.Toolbar
    Graphics.UI.Gtk.Misc.Accessible Graphics.UI.Gtk.Misc.Adjustment
    Graphics.UI.Gtk.Misc.Arrow Graphics.UI.Gtk.Misc.Calendar
    Graphics.UI.Gtk.Misc.DrawingArea Graphics.UI.Gtk.Misc.EventBox
    Graphics.UI.Gtk.Misc.GLArea Graphics.UI.Gtk.Misc.HandleBox
    Graphics.UI.Gtk.Misc.IMContextSimple
    Graphics.UI.Gtk.Misc.IMMulticontext Graphics.UI.Gtk.Misc.SizeGroup
    Graphics.UI.Gtk.Misc.Switch Graphics.UI.Gtk.Misc.Tooltip
    Graphics.UI.Gtk.Misc.Viewport Graphics.UI.Gtk.ModelView
    Graphics.UI.Gtk.ModelView.CellEditable
    Graphics.UI.Gtk.ModelView.CellLayout
    Graphics.UI.Gtk.ModelView.CellRenderer
    Graphics.UI.Gtk.ModelView.CellRendererAccel
    Graphics.UI.Gtk.ModelView.CellRendererCombo
    Graphics.UI.Gtk.ModelView.CellRendererPixbuf
    Graphics.UI.Gtk.ModelView.CellRendererProgress
    Graphics.UI.Gtk.ModelView.CellRendererSpin
    Graphics.UI.Gtk.ModelView.CellRendererSpinner
    Graphics.UI.Gtk.ModelView.CellRendererText
    Graphics.UI.Gtk.ModelView.CellRendererToggle
    Graphics.UI.Gtk.ModelView.CellView
    Graphics.UI.Gtk.ModelView.CustomStore
    Graphics.UI.Gtk.ModelView.IconView
    Graphics.UI.Gtk.ModelView.ListStore
    Graphics.UI.Gtk.ModelView.TreeDrag
    Graphics.UI.Gtk.ModelView.TreeModel
    Graphics.UI.Gtk.ModelView.TreeModelFilter
    Graphics.UI.Gtk.ModelView.TreeModelSort
    Graphics.UI.Gtk.ModelView.TreeRowReference
    Graphics.UI.Gtk.ModelView.TreeSelection
    Graphics.UI.Gtk.ModelView.TreeSortable
    Graphics.UI.Gtk.ModelView.TreeStore
    Graphics.UI.Gtk.ModelView.TreeView
    Graphics.UI.Gtk.ModelView.TreeViewColumn
    Graphics.UI.Gtk.Multiline.TextBuffer
    Graphics.UI.Gtk.Multiline.TextIter
    Graphics.UI.Gtk.Multiline.TextMark
    Graphics.UI.Gtk.Multiline.TextTag
    Graphics.UI.Gtk.Multiline.TextTagTable
    Graphics.UI.Gtk.Multiline.TextView Graphics.UI.Gtk.Ornaments.Frame
    Graphics.UI.Gtk.Ornaments.HSeparator
    Graphics.UI.Gtk.Ornaments.VSeparator
    Graphics.UI.Gtk.Printing.PageSetup
    Graphics.UI.Gtk.Printing.PaperSize
    Graphics.UI.Gtk.Printing.PrintContext
    Graphics.UI.Gtk.Printing.PrintOperation
    Graphics.UI.Gtk.Printing.PrintSettings
    Graphics.UI.Gtk.Recent.RecentChooser
    Graphics.UI.Gtk.Recent.RecentChooserMenu
    Graphics.UI.Gtk.Recent.RecentChooserWidget
    Graphics.UI.Gtk.Recent.RecentFilter
    Graphics.UI.Gtk.Recent.RecentInfo
    Graphics.UI.Gtk.Recent.RecentManager
    Graphics.UI.Gtk.Scrolling.HScrollbar
    Graphics.UI.Gtk.Scrolling.ScrolledWindow
    Graphics.UI.Gtk.Scrolling.VScrollbar
    Graphics.UI.Gtk.Selectors.ColorButton
    Graphics.UI.Gtk.Selectors.ColorSelection
    Graphics.UI.Gtk.Selectors.ColorSelectionDialog
    Graphics.UI.Gtk.Selectors.FileChooser
    Graphics.UI.Gtk.Selectors.FileChooserButton
    Graphics.UI.Gtk.Selectors.FileChooserDialog
    Graphics.UI.Gtk.Selectors.FileChooserWidget
    Graphics.UI.Gtk.Selectors.FileFilter
    Graphics.UI.Gtk.Selectors.FontButton
    Graphics.UI.Gtk.Selectors.FontSelection
    Graphics.UI.Gtk.Selectors.FontSelectionDialog
    Graphics.UI.Gtk.Selectors.HSV Graphics.UI.Gtk.Windows.AboutDialog
    Graphics.UI.Gtk.Windows.Assistant Graphics.UI.Gtk.Windows.Dialog
    Graphics.UI.Gtk.Windows.Invisible
    Graphics.UI.Gtk.Windows.MessageDialog
    Graphics.UI.Gtk.Windows.OffscreenWindow
    Graphics.UI.Gtk.Windows.Window Graphics.UI.Gtk.Windows.WindowGroup
    Graphics.UI.GtkInternals
hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                Graphics.UI.Gtk.Gdk.PixbufData Graphics.UI.Gtk.General.Structs
                Graphics.UI.Gtk.ModelView.Types Graphics.UI.Gtk.ModelView.Sequence
                Graphics.UI.Gtk.Multiline.Types
                Graphics.UI.Gtk.Abstract.ContainerChildProperties
                Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
abi: 4999a161d24de5f038cabea417a8ac0e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gtk3-0.14.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/gtk3-0.14.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk
hs-libraries: HSgtk3-0.14.8-1FoJ0CzaPbTJYdJ9HSy7RX
extra-libraries:
    gthread-2.0 gtk-3 gdk-3 pangocairo-1.0 pango-1.0 atk-1.0
    cairo-gobject cairo gdk_pixbuf-2.0 gio-2.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/gtk-3.0 /usr/include/at-spi2-atk/2.0
              /usr/include/at-spi-2.0 /usr/include/dbus-1.0
              /usr/lib/dbus-1.0/include /usr/include/gio-unix-2.0/
              /usr/include/cairo /usr/include/libdrm /usr/include/pango-1.0
              /usr/include/atk-1.0 /usr/include/pixman-1 /usr/include/freetype2
              /usr/include/libpng16 /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/gdk-pixbuf-2.0
depends:
    base-4.10.1.0 array-0.5.2.0 containers-0.5.10.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    glib-0.13.5.0-BeAc7OfNXQoLFL8f9OJjxh
    pango-0.13.4.0-9Tq9kbdD0ux7FY4BsNo9Py
    cairo-0.13.4.2-Dw8Q4OMoxeCeIJxfgPTYN
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             glib-0.13.5.0-BeAc7OfNXQoLFL8f9OJjxh=5806e3854455ad0234d765b23ad774c8
             pango-0.13.4.0-9Tq9kbdD0ux7FY4BsNo9Py=d6545bf58ee0515b92097ed2b160c5e1
             cairo-0.13.4.2-Dw8Q4OMoxeCeIJxfgPTYN=0e668a913017a7446ce6ea0cdd858dab
ld-options: -pthread
haddock-interfaces: /usr/share/doc/haskell-gtk/html/gtk3.haddock
haddock-html: /usr/share/doc/haskell-gtk/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
